@@ -1,7 +1,7 @@
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2021, UChicago Argonne, LLC
+# :copyright: (c) 2017-2022, UChicago Argonne, LLC
 #
 # Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
 #
@@ -12,7 +12,7 @@ __project__ = u"apstools"
 __description__ = (
     u"Various Python tools for use with the Bluesky Framework at the APS"
 )
-__copyright__ = u"2017-2021, UChicago Argonne, LLC"
+__copyright__ = u"2017-2022, UChicago Argonne, LLC"
 __authors__ = [
     u"Pete Jemian",
 ]
@@ -24,8 +24,8 @@ __license__ = u"(c) " + __copyright__
 __license__ += u" (see LICENSE.txt file for details)"
 __platforms__ = "any"
 __zip_safe__ = False
-__exclude_project_dirs__ = "docs examples tests".split()
-__python_version_required__ = ">=3.7"
+__exclude_project_dirs__ = "docs resources".split()
+__python_version_required__ = ">=3.7, <3.10"
 
 __package_name__ = __project__
 __long_description__ = __description__
@@ -48,6 +48,7 @@ __classifiers__ = [
     "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
+    "Programming Language :: Python :: 3.10",
     "Topic :: Scientific/Engineering",
     "Topic :: Scientific/Engineering :: Astronomy",
     "Topic :: Scientific/Engineering :: Bio-Informatics",
